@@ -2,7 +2,7 @@
 /*
  * UNFS3 server framework
  * Originally generated using rpcgen
- * Portions (C) 2004, Pascal Schmidt <der.eremit@email.de>
+ * Portions (C) 2004, Pascal Schmidt
  * see file LICENSE for license details
  */
 
@@ -45,7 +45,7 @@
 #define SIG_PF void(*)(int)
 #endif
 
-#define UNFS_NAME "UNFS3 unfsd 0.9.13 (C) 2004 Pascal Schmidt <der.eremit@email.de>\n"
+#define UNFS_NAME "UNFS3 unfsd 0.9.15 (C) 2006, Pascal Schmidt <unfs3-server@ewetel.net>\n"
 
 /* write verifier */
 writeverf3 wverf;
@@ -100,6 +100,14 @@ struct in_addr get_remote(struct svc_req *rqstp)
     return (svc_getcaller(rqstp->rq_xprt))->sin_addr;
 }
 
+/*
+ * return remote port from svc_req structure
+ */
+short get_port(struct svc_req *rqstp)
+{
+    return (svc_getcaller(rqstp->rq_xprt))->sin_port;
+}
+
 /*
  * parse command line options
  */
@@ -182,7 +190,7 @@ static void parse_options(int argc, char **argv)
 		break;
 	    case 's':
 		opt_singleuser = TRUE;
-		if (getuid() == 0) {
+		if (backend_getuid() == 0) {
 		    logmsg(LOG_WARNING,
 			   "Warning: running as root with -s is dangerous");
 		    logmsg(LOG_WARNING,
