@@ -1,7 +1,7 @@
 
 /*
  * UNFS3 NFS protocol procedures
- * (C) 2004, Pascal Schmidt <der.eremit@email.de>
+ * (C) 2004, Pascal Schmidt
  * see file LICENSE for license details
  */
 
@@ -53,8 +53,8 @@
  */
 #define PREP(p,f) do {						\
                       unfs3_fh_t *fh = (void *)f.data.data_val; \
-                      setegid(0);                               \
-                      seteuid(0);                               \
+                      backend_setegid(0);                       \
+                      backend_seteuid(0);                       \
                       p = fh_decomp(f);				\
                       if (exports_options(p, rqstp, NULL, NULL) == -1) { \
                           memset(&result, 0, sizeof(result));	\
